# delimit ;
clear all;
set mem 100m;
set more off;
set scheme s2mono;
set scheme s2color;
set seed 13467743;

/*SET FILE DIRECTORY HERE:*/
global filepath "~\Dropbox\GT_Index\Replication\Replication_Final";


/*local directory for output so don't hang up Dropbox in loops:*/
global localdir "C:\Users\ctmcintosh\Documents\Projects\Guatemala Index";



#delimit cr

/*Opening the replication data file:*/
use "$filepath\GT_Index_Replication_Data", clear


cd "$localdir"

/*Start code for all Tables and Figures from this point:*/
STOP;










/*************************************************TABLES AND FIGURES FROM THE PAPER:*****************************************************/
/*TABLE 1:  Composite of structural features of games, plus game-level averages of wtp_usd and wtphat_usd:*/
/*SUMSTATS BY ROUND:*/
#delimit;
preserve;
collapse wtp_usd wtphat_usd   worst , by(game);
restore;

/*TABLE 2:  Utility parameters from structural estimation.*/
#delimit;
sum bhat khat dhat if round==10, detail;


/*TABLE 3*/
/*DROUGHT:*/
#delimit;
areg wtphat_usd drought uninssdm_drought uninssdm_nodrought if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se replace;
areg wtphat_usd  milddrought worst if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se append;
areg wtp_usd  drought  uninssdm_drought uninssdm_nodrought if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se append;
areg wtp_usd  milddrought worst if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se append;
areg wtp_usd wtphat_usd milddrought worst if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se append;
areg wtpusd_dif milddrought worst if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id);
outreg2 using "table1", bdec(2) se append;
/*BOOTSTRAPPING OF COEFFICIENT ON WTP_HAT IN COLUMN 5:*/
/*note that this code only bootstraps the behavioral parameters because none of the risk exposure parameters are estimated.*/
#delimit;
preserve;
save final_data, replace;
/*Bootstrapping code using the 300 runs aversionm for each individual:*/
clear;
gen _r=.;
save temp_b, replace;
forvalues x = 1/300  {;
		use "$filepath\bootstrapvalues_aversionm";
		quietly keep if rep==`x';
		quietly save temp_data, replace;
        quietly use final_data, clear;
		quietly merge m:1 participant_id  using temp_data;
        bsample, cluster(participant_id);
		areg wtp_usd wtphat_usd milddrought worst if (round>=3 & round<=15), absorb(participant_id); 
		gen _b1_wtphat = _b[wtphat_usd];
        collapse _b*;		
        append using temp_b;
        quietly save temp_b, replace;
		display `x';
        };
#delimit;
use temp_b, clear;
foreach y in 1_wtphat
	{;
        egen SE_`y' = sd(_b`y');
        };
sum SE*	;	


/*TABLE 4:*/
/*CORRELATES OF PROSPECT:*/
reg wtp_disp_prosp aversionm ambigaversion trustindex somerisk* mainrisk* if round==10
outreg2 using "prospect", sum bdec(2) se replace
reg wtp_disp_prosp aversionm ambigaversion trustindex if round==10
outreg2 using "prospect",  bdec(2) se append
reg wtp_disp_prosp aversionm ambigaversion trustindex somerisk* if round==10
testparm somerisk*
local Fothrisk=r(F)
outreg2 using "prospect",  bdec(2) se append addstat(F_Some Risk, `Fothrisk')
reg wtp_disp_prosp aversionm ambigaversion trustindex mainrisk* if round==10
testparm mainrisk*
local Fothrisk=r(F)
outreg2 using "prospect",  bdec(2) se append addstat(F_Main Risk, `Fothrisk')
reg wtp_disp_prosp aversionm ambigaversion trustindex i.rainriskrank i.droughtriskrank i.windriskrank i.plagueriskrank if round==10
testparm i.rainriskrank i.droughtriskrank i.windriskrank 
local Fothrisk=r(F)
outreg2 aversionm ambigaversion trustindex using "prospect",  bdec(2) se append addstat(F_Main Risk, `Fothrisk')

/*BOOTSTRAPPED VERSION OF CORRELATES OF TABLE 4:*/
/*note that this code only bootstraps the behavioral parameters because none of the risk exposure parameters are estimated.*/
#delimit;
preserve;
save final_data, replace;
/*Bootstrapping code using the 300 runs aversionm for each individual:*/
#delimit;
clear;
gen _r=.;
save temp_b, replace;
forvalues x = 1/300  {;
		use "$filepath\bootstrapvalues_aversionm";
		quietly keep if rep==`x';
		quietly save temp_data, replace;
        quietly use final_data, clear;
		quietly merge m:1 participant_id  using temp_data;
        bsample, cluster(participant_id);
		reg wtp_disp_prosp aversionm ambigaversion trustindex if round==10	;	        
		foreach y in aversionm ambigaversion trustindex {;
                gen _b1_`y'=_b[`y'];
                };	
		reg wtp_disp_prosp aversionm ambigaversion trustindex education testtotal if round==10	;	        
		foreach y in aversionm ambigaversion trustindex {;
                gen _b2_`y'=_b[`y'];
                };	
	    reg wtp_disp_prosp aversionm ambigaversion trustindex somerisk* if round==10;
		        foreach y in aversionm ambigaversion trustindex {;
                gen _b3_`y'=_b[`y'];
                };
		reg wtp_disp_prosp aversionm ambigaversion trustindex mainrisk* if round==10;
		foreach y in  aversionm ambigaversion trustindex {;
				gen _b4_`y'=_b[`y'];
				};
		reg wtp_disp_prosp aversionm ambigaversion trustindex i.rainriskrank i.droughtriskrank i.windriskrank i.plagueriskrank if round==10;
		foreach y in  aversionm ambigaversion trustindex {;
				gen _b5_`y'=_b[`y'];
				};

        collapse _b*;		
        append using temp_b;
        quietly save temp_b, replace;
		display `x';
        };
#delimit;
use temp_b, clear;
foreach y in 1_aversionm 1_ambigaversion 1_trustindex 2_aversionm 2_ambigaversion 2_trustindex 
		3_aversionm 3_ambigaversion 3_trustindex 4_aversionm 4_ambigaversion 4_trustindex 
		5_aversionm 5_ambigaversion 5_trustindex
	{;
        egen SE_`y' = sd(_b`y');
        };
sum SE*	;	





/*TABLE 5*/
/*HET RISK AVERSION:*/
#delimit;
preserve;
foreach x in aversionm  {;
     gen `x'_milddrought=`x' * milddrought;
	 gen `x'_drought=`x' * drought;
	 gen `x'_worst=`x'*worst;
	 gen `x'_nodrought=`x'*(1-drought)  ; 
     };
reg wtphat_usd  aversionm_milddrought  aversionm_worst aversionm  milddrought worst if round==6 | (round>=10 & round<=15), cluster(participant_id) ;
outreg2 using "Heterog", bdec(2) se replace;
reg wtp_usd  aversionm_milddrought  aversionm_worst aversionm  milddrought worst if round==6 | (round>=10 & round<=15), cluster(participant_id) ;
outreg2 using "Heterog", bdec(2) se append;
restore;

/*BOOTSTRAPPED VERSION OF TABLE 5:*/
#delimit;
preserve;
save final_data, replace;
/*Bootstrapping code using the 300 runs aversionm for each individual:*/
clear;
gen _r=.;
save temp_b, replace;
forvalues x = 1/300  {;
		use "$filepath\bootstrapvalues_aversionm";
		quietly keep if rep==`x';
		quietly save temp_data, replace;
        quietly use final_data, clear;
		quietly merge m:1 participant_id  using temp_data;
	foreach x in aversionrepm  {;
     gen `x'_milddrought=`x' * milddrought;
	 gen `x'_drought=`x' * drought;
	 gen `x'_worst=`x'*worst;
	 gen `x'_nodrought=`x'*(1-drought)  ; 
     };

        bsample, cluster(participant_id);
		reg wtphat_usd  aversionrepm_milddrought  aversionrepm_worst aversionrepm  milddrought worst if round==6 | (round>=10 & round<=15), cluster(participant_id) ;
		        foreach y in  aversionrepm_milddrought  aversionrepm_worst aversionrepm  milddrought worst {;
                gen _b1_`y'=_b[`y'];
                };	
		reg wtp_usd  aversionrepm_milddrought  aversionrepm_worst aversionrepm  milddrought worst if round==6 | (round>=10 & round<=15), cluster(participant_id) ;
		        foreach y in  aversionrepm_milddrought  aversionrepm_worst aversionrepm  milddrought worst {;
                gen _b2_`y'=_b[`y'];
                };
        collapse _b*;		
        append using temp_b;
        quietly save temp_b, replace;
		display `x';
        };
#delimit;
use temp_b, clear;
foreach y in 1_aversionrepm_milddrought  1_aversionrepm_worst 1_aversionrepm  1_milddrought 1_worst 
	2_aversionrepm_milddrought  2_aversionrepm_worst 2_aversionrepm  2_milddrought 2_worst
	{;
        egen SE_`y' = sd(_b`y');
        };
sum SE*	;	



/*TABLE 6:*/
# delimit ;
preserve;
gen group_partial_low = (ex_code==23);
gen group_partial_med = (ex_code==25);
gen group_partial_high = (ex_code==27);
gen group_full_low = (ex_code==24);
gen group_full_med = (ex_code==26);
gen group_full_high = (ex_code==28);
gen group_nostip_low = (ex_code==19);
gen group_nostip_med = (ex_code==20);
gen group_nostip_high = (ex_code==21); 
gen group_nostip = (ex_code==19) | (ex_code==20) | (ex_code==21);
gen trust_group_nostip = trust_group * group_nostip;
gen testgroup=(testp07ok+testp08ok)*(ex_code>=19&ex_code<=28);
gen test_medrisk=(testp07ok+testp08ok)* medrisk;
gen test_highrisk=(testp07ok+testp08ok)* highrisk;
areg wtphat_usd noshare partshare fullshare if smallrisk==1 & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) replace;
areg wtp_usd noshare partshare fullshare if smallrisk==1 & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd noshare partshare fullshare medrisk highrisk if (smallrisk==1 | medrisk==1 | highrisk==1) & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd noshare partshare fullshare medrisk highrisk testgroup if (smallrisk==1 | medrisk==1 | highrisk==1) & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
lincom noshare+2*testgroup;
areg wtp_usd noshare partshare fullshare medrisk highrisk testgroup test_medrisk test_highrisk if (smallrisk==1 | medrisk==1 | highrisk==1) & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd noshare partshare fullshare medrisk highrisk trust_group  if (smallrisk==1 | medrisk==1 | highrisk==1) & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd noshare partshare fullshare medrisk highrisk trust_group trust_medrisk trust_highrisk if (smallrisk==1 | medrisk==1 | highrisk==1) & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
/*How much loss adjustment do the groups expect?  
Comparison of ex_code 19-21 (unstipulated) to ex_codes 22-28 (stipulated)*/
areg wtp_usd noshare partshare fullshare group_nostip if smallrisk==1 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd group_nostip noshare partshare fullshare medrisk highrisk  if (smallrisk==1 | medrisk==1 | highrisk==1) [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
areg wtp_usd group_nostip noshare partshare fullshare medrisk highrisk trust_group trust_group_nostip if (smallrisk==1 | medrisk==1 | highrisk==1) [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
restore;



/*FIGURE 3:*/
/*Plotting estimated versus actual against background risk:*/
#delimit;
preserve;
gen sdincins_sq = sdincins^2;
gen first = (ex_code>=3 & ex_code<=9);
keep if (ex_code>=3 & ex_code<=15);
regr wtp_usd sdincins sdincins_sq if first==0;
predict fwtp_late if e(sample);
regr wtp_usd sdincins sdincins_sq if first==1;
predict fwtp_early if e(sample);
regr wtphat_usd sdincins sdincins_sq if first==0;
predict fwtphat_late if e(sample);
regr wtphat_usd sdincins sdincins_sq if first==1;
predict fwtphat_early if e(sample);
gen wtp_early = wtp_usd if first==1;
gen wtp_late = wtp_usd if first==0;
gen wtphat_early = wtphat_usd if first==1;
gen wtphat_late = wtphat_usd if first==0;
collapse wtp_early wtp_late wtphat_early wtphat_late fwtp_early fwtp_late fwtphat_early fwtphat_late (first) game, by(sdincins);
tw  scatter wtp_early sdincins , mlabel(game)|| scatter wtp_late sdincins , msymbol(T) mlabel(game) || scatter wtphat_early sdincins , msymbol(Oh)|| scatter wtphat_late sdincins, msymbol(Th) ||
	line fwtp_early sdincins || line fwtp_late sdincins , lwidth(thick) || line fwtphat_early sdincins , lpattern(-)  
	|| line fwtphat_late sdincins ,lpattern(-) lwidth(thick)
	ytitle("WTP, US$") xtitle("SD of Income if Insured in Game")  
	legend(label(1 "Actual WTP, Partial") label(2 "Actual WTP, Probabilistic") label(3 "Predicted WTP, Partial") label(4 "Predicted WTP, Probabilistic") 
	label (5 "Fitted Actual, Partial") label (6 "Fitted Actual, Probabilistic") label (7 "Fitted Predicted, Partial") label (8 "Fitted Predicted, Probabilistic")) 
	text( 18  310 "worst", place(e)) text( 18  440 "worst", place(e)) ; 
restore;










/*********************************************************************************************************/
/*APPENDIX TABLES:*/


/*APPENDIX TABLE A1:  MECHANICAL FROM STRUCTURE OF GAMES.*/


/*APPENDIX TABLE A2:  REPRESENTIVITY OF GAME PLAYERS RELATIVE TO COOP MEMBERSHIP:*/

preserve
use "$filepath/cooperative_sample", clear
xtset Cooperativa
xtreg age game, fe 
outreg2  using "$results/test", bdec(2) replace
foreach x in female education  area asset{
display "`x'"
xtreg `x' game,fe
outreg2 game using "$results/test", bdec(2) append
}
restore




/*APPENDIX TABLE C1:  MECHANICAL FROM STRUCTURE OF GAMES.*/


/*APPENDIX TABLE C2:  EFFECT OF GAME ORDERING.*/
/*Testing for ordering & pricing effects using the randomized sequencing:*/
#delimit;
preserve;
drop if p_base==1 | p_base==9 | p_base==10;						//FP, March 24;
gen random_games =  (period=="group  Correlation") | (period=="group  Het") | (period=="indiv  EL") | (period=="indiv  SDL") ;
tab random_games;
tab ex_code if random_games==1;
tab ex_code order if random_games==1, missing;
gen group = (period=="group  No Rule") | (period=="group  Correlation") | (period=="group  Het") ;
gen group_after = (order>=5 & order<=8);       //corrected 5/14/16;   
replace group_after=. if order==.  ;         //corrected 5/14/16;
gen group_after_int = group_after * group;
gen sdl_after = (order==1 | order==3 | order==5 | order==7);
gen sdl = (period=="indiv  SDL");
gen sdl_after_int = sdl_after* sdl;
gen het_after = (order==1 | order==2 | order==5 | order==6);
*gen het = (period=="group  Het");
gen het_after_int = het_after * het; 
reg mean_wtp high_price if ex_code==3 ,  cluster(coop_id);
outreg2  using "$results\table",  bdec(2) replace;
areg wtp_usd game_order i.ex_code if ex_code>=3 & ex_code<=36, absorb(participant_id) cluster(participant_id);
outreg2 game_order using "$results\table",  bdec(2) append;
areg wtp_usd  group_after_int  group  if random_games==1, absorb(participant_id) cluster(participant_id);
outreg2 using "$results\table",  bdec(2) append;
areg wtp_usd   group_after_int  group sdl_after_int  sdl het_after_int  het   if random_games==1, absorb(participant_id) cluster(participant_id);
outreg2 using "$results\table",  bdec(2) append;
restore;



/*APPENDIX TABLE C3:  EFFECT OF DROUGHT GAME ORDERING.*/

#delimit;
preserve;
gen grpafter = (order>=5 & order<=8);
replace grpafter=. if order==.;
gen drought_grpafter=drought*grpafter;
gen nonworst_grpafter=milddrought*grpafter;
gen worst_grpafter=worst*grpafter;
areg wtphat_usd drought drought_grpafter uninssdm_drought uninssdm_nodrought if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se replace;
areg wtp_usd  drought drought_grpafter uninssdm_drought uninssdm_nodrought if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id); 
outreg2 using "table1", bdec(2) se append;
areg wtpusd_dif milddrought nonworst_grpafter worst worst_grpafter if (round>=3 & round<=15), absorb(participant_id) cluster(participant_id);
outreg2 using "table1", bdec(2) se append;
restore;




/*APPENDIX TABLE C4:  EFFECT OF GROUP GAME ORDERING.*/
#delimit;
preserve;
gen grpafter = (order>=5 & order<=8);
replace grpafter=. if order==.;
tab order grpafter;
foreach x in noshare partshare fullshare {;
gen `x'_grpafter=`x'*grpafter;
};
areg wtphat_usd noshare partshare fullshare noshare_grpafter partshare_grpafter fullshare_grpafter if smallrisk==1 & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) replace;
areg wtp_usd noshare partshare fullshare noshare_grpafter partshare_grpafter fullshare_grpafter if smallrisk==1 & not_stipulated==0 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/grpsharing", bdec(2) append;
restore;


/*APPENDIX TABLE C5:  FRAMED VERSUS UNFRAMED.*/
#delimit;
areg wtphat_usd framed [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "table", bdec(2) replace;
areg wtphat_usd framed framed_medvar framed_highvar medvar highvar [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "table", bdec(2) append;
areg wtp_usd framed [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "table", bdec(2) append;
areg wtp_usd framed framed_medvar framed_highvar medvar highvar [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "table", bdec(2) append;


/*APPENDIX FIGURE C.1.  FRAMED VERSUS UNFRAMED GAMES:*/
#delimit;
preserve;
gen actual_framed = wtp_usd if (game=="I1" | game=="I2" | game=="I3");
gen actual_unframed = wtp_usd if (game=="I14" | game=="I15" | game=="I16");
gen estimated_unframed = wtphat_usd if (game=="I14" | game=="I15" | game=="I16");
gen risk = "1. low" if (game=="I1" | game=="I14");
replace risk = "2. medium" if (game=="I2" | game=="I15");
replace risk = "3. high" if (game=="I3"| game=="I16");
graph bar actual_framed actual_unframed estimated_unframed, over(risk) nooutside  blabel(total) legend(label(1 "Framed WTP") label(2 "Actual Unframed WTP") label(3 "Predicted Unframed WTP"))
	title("Effect of Framing on WTP") subtitle("By risk level in game") ytitle("WTP, US$") ;
collapse actual_framed actual_unframed estimated_unframed, by(risk);
list;
restore;


/*APPENDIX TABLE D.1:  GROUP DELIBERATION:*/
/*this game doesn't have the same panel structure as the rest, so is analyzed in a cross section (arbitrarily ex_code==1)*/
#delimit;
global covars "female education  wealth trustindex aversionm ambigaversion ";
regr G12A_sh perdida $covars if missing==0, cluster(coop_id);
outreg2 using "$results/table", bdec(4) replace  ctitle("Prior");
preserve;
keep if ex_code==1 & missing==0;
collapse what_agree perdida $covars ex_code missing, by(coop_id);
regr what_agree perdida $covars if ex_code==1 &  missing==0;
outreg2 using "$results/table", bdec(4) append  ctitle("group decision");
restore;
xtreg shock_dif perdida $covars if missing==0, i(coop_id) fe cluster(coop_id);
outreg2 using "$results/table", bdec(4) append  ctitle("shock_dif");


/*APPENDIX TABLE D.2:  GROUP HETEROGENEITY:
GAMES: G7-G11 (ex_code= 29 to 33)*/
# delimit ;
areg wtp_usd het if (ex_code==27 | ex_code==29) [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/table9", bdec(2) replace excel ctitle("ex-code 27/29");
areg wtphat_usd trans2other if ex_code>=29 & ex_code<=33 [aw=ipw], absorb(participant_id) cluster(participant_id) ;
outreg2 using "$results/table9", bdec(2) append ctitle("Fitted");
areg wtp_usd trans2other  if ex_code>=29 & ex_code<=33 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/table9", bdec(4) append excel ctitle("Actual") ;
areg wtphat_usd high_provider low_provider  low_receiver high_receiver  if ex_code>=29 & ex_code<=33 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/table9", bdec(2) append ctitle("Fitted");
areg wtp_usd high_provider low_provider  low_receiver high_receiver  if ex_code>=29 & ex_code<=33 [aw=ipw], absorb(participant_id) cluster(participant_id);
outreg2 using "$results/table9", bdec(2) append ctitle("Actual");
test high_provider=-high_receiver;
test low_provider=-low_receiver;






